translate.misc.typecheck.typeclasses

Package translate :: Package misc :: Package typecheck :: Module typeclasses |
[hide private]
[frames] | no frames]

# Module typeclasses

source code

Variables | [hide private]
| Number = `Typeclass(* _numbers)`
| String = `Typeclass(str, unicode)`
| ImSequence = `Typeclass(tuple, xrange, String)`
| MSequence = `Typeclass(list)`
| Mapping = `Typeclass(dict)`
| __package__ = ``'``translate.misc.typecheck``'``

Imports: Typeclass